@@ -1719,16 +1719,17 @@ class VariableClUpdateWithBdepsSet(Variable):
     """
     Добавление --with-bdeps при вызове emerge
     """
-    type = Variable.Types.Boolean
-    value = Variable.On
+    type = Variable.Types.Tristate
+    value = Variable.Auto
 
 
 class VariableClUpdateWithBdepsOptSet(Variable):
     """
     Добавление --with-bdeps при вызове emerge (опция)
     """
-    type = Variable.Types.Boolean
+    type = Variable.Types.Tristate
     opt = ["--with-bdeps"]
+    metavalue = "ON/OFF/AUTO"
 
     def init(self):
         self.help = _("save packages used during build")
